<?php

namespace Drupal\drd_pi;

use Drupal\drd\Entity\BaseInterface;

/**
 * Provides abstract class for platform based entities.
 */
abstract class DrdPiEntity implements DrdPiEntityInterface {

  /**
   * Account to which this entity is attached.
   *
   * @var DrdPiAccountInterface
   */
  protected $account;

  /**
   * Label of this entity.
   *
   * @var string
   */
  protected $label;

  /**
   * ID of this entity.
   *
   * @var string
   */
  protected $id;

  /**
   * DrdEntity which matches this DrdPiEntity.
   *
   * @var \Drupal\drd\Entity\BaseInterface
   */
  protected $entity;

  /**
   * Construct a DrdPiEntity object.
   *
   * @param DrdPiAccountInterface $account
   *   Account to which this entity is attached.
   * @param string $label
   *   Label of this entity.
   * @param string $id
   *   ID of this entity.
   */
  public function __construct(DrdPiAccountInterface $account, $label, $id) {
    $this->account = $account;
    $this->label = $label;
    $this->id = $id;
  }

  /**
   * {@inheritdoc}
   */
  public function id() {
    return $this->id;
  }

  /**
   * {@inheritdoc}
   */
  public function label() {
    return $this->label;
  }

  /**
   * {@inheritdoc}
   */
  public function setDrdEntity(BaseInterface $entity) {
    $this->entity = $entity;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getDrdEntity() {
    return $this->entity;
  }

  /**
   * {@inheritdoc}
   */
  public function hasDrdEntity() {
    return !empty($this->entity);
  }

}
