<?php

namespace Drupal\drd\Plugin\Action;

use Drupal\drd\Entity\BaseInterface as RemoteEntityInterface;
use Symfony\Component\Filesystem\Filesystem;

/**
 * Provides a 'Info' action.
 *
 * @Action(
 *  id = "drd_action_info",
 *  label = @Translation("Info"),
 *  type = "drd_domain",
 * )
 */
class Info extends BaseEntityRemote {

  /**
   * {@inheritdoc}
   */
  public function executeAction(RemoteEntityInterface $domain) {
    $response = parent::executeAction($domain);
    if ($response) {
      /* @var \Drupal\drd\Entity\DomainInterface $domain */
      if (!empty($response['settings']['container_yamls'])) {
        // Change container_yamls to relative paths.
        $fs = new Filesystem();
        $container_yamls = [];
        foreach ($response['settings']['container_yamls'] as $container_yaml) {
          if (strpos($container_yaml, '/redis/') === FALSE) {
            $container_yamls[] = trim($fs->makePathRelative($container_yaml, $response['root']), '/');
          }
        }
        $response['settings']['container_yamls'] = $container_yamls;
      }

      $domain
        ->setName($response['name'])
        ->cacheGlobals($response['globals'])
        ->cacheRequirements($response['requirements'])
        ->cacheSettings($response['settings'])
        ->cacheVariables($response['variables'])
        ->cacheReview($response['review'])
        ->save();
      return $response;
    }
    return FALSE;
  }

}
